.. _commands:

Commands
********

.. Use a hidden table of contents to ensure that documentation is read.

.. include:: commands/toc.rst

Charmcraft has several commands used for managing the building, uploading and releasing
of a charm.

.. include:: commands/basic-commands.rst


Lifecycle Commands
==================

.. include:: commands/lifecycle-commands.rst


Store Commands
==============

Store commands fall into several categories, depending on the particular command.

Account Commands
----------------

.. include:: commands/store (account)-commands.rst

Charm or Bundle Commands
------------------------

.. include:: commands/store (charm or bundle)-commands.rst

Library Commands
----------------

.. include:: commands/store (libraries)-commands.rst

Extensions-related Commands
===========================

.. include:: commands/extensions-commands.rst

Other Commands
==============

.. include:: commands/other-commands.rst
